Modules
================

astromer
------------------------

.. automodule:: ASTROMER.core.astromer
   :members:
   :undoc-members:
   :show-inheritance:

attention
-------------------------

.. automodule:: ASTROMER.core.attention
   :members:
   :undoc-members:
   :show-inheritance:

classifier
--------------------------

.. automodule:: ASTROMER.core.classifier
   :members:
   :undoc-members:
   :show-inheritance:

data
--------------------

.. automodule:: ASTROMER.core.data
   :members:
   :undoc-members:
   :show-inheritance:

encoder
-----------------------

.. automodule:: ASTROMER.core.encoder
   :members:
   :undoc-members:
   :show-inheritance:

losses
----------------------

.. automodule:: ASTROMER.core.losses
   :members:
   :undoc-members:
   :show-inheritance:

masking
-----------------------

.. automodule:: ASTROMER.core.masking
   :members:
   :undoc-members:
   :show-inheritance:

metrics
-----------------------

.. automodule:: ASTROMER.core.metrics
   :members:
   :undoc-members:
   :show-inheritance:

output
----------------------

.. automodule:: ASTROMER.core.output
   :members:
   :undoc-members:
   :show-inheritance:

plots
---------------------

.. automodule:: ASTROMER.core.plots
   :members:
   :undoc-members:
   :show-inheritance:

positional
--------------------------

.. automodule:: ASTROMER.core.positional
   :members:
   :undoc-members:
   :show-inheritance:

scheduler
-------------------------

.. automodule:: ASTROMER.core.scheduler
   :members:
   :undoc-members:
   :show-inheritance:

tboard
----------------------

.. automodule:: ASTROMER.core.tboard
   :members:
   :undoc-members:
   :show-inheritance:

utils
---------------------

.. automodule:: ASTROMER.core.utils
   :members:
   :undoc-members:
   :show-inheritance:

